@@ -24,6 +24,10 @@ test_that("list_inference_profiles", {
   expect_error(svc$list_inference_profiles(), NA)
 })
 
+test_that("list_marketplace_model_endpoints", {
+  expect_error(svc$list_marketplace_model_endpoints(), NA)
+})
+
 test_that("list_model_copy_jobs", {
   expect_error(svc$list_model_copy_jobs(), NA)
 })
@@ -40,6 +44,10 @@ test_that("list_model_invocation_jobs", {
   expect_error(svc$list_model_invocation_jobs(), NA)
 })
 
+test_that("list_prompt_routers", {
+  expect_error(svc$list_prompt_routers(), NA)
+})
+
 test_that("list_provisioned_model_throughputs", {
   expect_error(svc$list_provisioned_model_throughputs(), NA)
 })
